[−][src]Struct rendy_core::hal::pso::Sided

pub struct Sided<T> {
    pub front: T,
    pub back: T,
}

A generic struct holding the properties of two sides of a polygon.

Fields

front: T

Information about the front face.

back: T

Information about the back face.

Implementations

impl<T> Sided<T> where
    T: Copy, 
[src]

pub fn new(value: T) -> Sided<T>[src]

Create a new Sided structure with both front and back holding the same value.